@@ -34,11 +34,9 @@
 #'
 #' @section Methods:
 #' * `score(measures = NULL, task = NULL, learner = NULL)`\cr
-#'   (`list()` of [Measure], [Task], [Learner]) -> [Prediction]\cr
+#'   (list of [Measure], [Task], [Learner]) -> [Prediction]\cr
 #'   Calculates the performance for all provided measures
-#'   If no measure is provided, defaults to the measure defined in [mlr_reflections$default_measures][mlr_reflections]
-#'   ([mlr_measures_classif.ce] for classification and [mlr_measures_regr.mse] for regression).
-#'   [Task] and [Learner] may be `NULL` for many measures, but some measures need to extract information
+#'   [Task] and [Learner] may be `NULL` for most measures, but some measures need to extract information
 #'   from these objects.
 #'
 #' @section S3 Methods:
@@ -69,12 +67,12 @@ Prediction = R6Class("Prediction",
       } else {
         data = as.data.table(self)
         catf("%s for %i observations:", format(self), nrow(data))
-        print(data, nrows = 10L, topn = 3L, print.class = TRUE, print.keys = FALSE)
+        print(data, nrows = 10L, topn = 3L, class = FALSE, row.names = FALSE, print.keys = FALSE)
       }
     },
 
     score = function(measures = NULL, task = NULL, learner = NULL, train_set = NULL) {
-      measures = assert_measures(measures, task_type = self$task_type, task = task, learner = learner)
+      measures = assert_measures(as_measures(measures, task_type = self$task_type), task = task, learner = learner)
       scores = map_dbl(measures, function(m) m$score(prediction = self, task = task, learner = learner, train_set = train_set))
       set_names(scores, ids(measures))
     }
@@ -84,7 +82,9 @@ Prediction = R6Class("Prediction",
     row_ids = function() self$data$row_ids,
     truth = function() self$data$truth,
     predict_types = function() setdiff(names(self$data), c("row_ids", "truth")),
-    missing = function() { self$data$row_ids[0L] } # empty vector
+    missing = function() {
+      self$data$row_ids[0L]
+    } # empty vector
   )
 )
 
