@@ -1,12 +1,20 @@
 #' @title Subsampling Resampling
 #'
+#' @usage NULL
 #' @aliases mlr_resamplings_subsampling
 #' @format [R6::R6Class] inheriting from [Resampling].
 #' @include Resampling.R
 #'
+#' @section Construction:
+#' ```
+#' ResamplingSubsampling$new()
+#' mlr_resamplings$get("subsampling")
+#' rsmp("subsampling")
+#' ```
+#'
 #' @description
-#' `repeats` (default: 30) times repeated splits into training and test set
-#' with a ratio of `ratio` (default: 2/3) observations in the training set.
+#' Splits data `repeats` (default: 30) times into training and test set
+#' with a ratio of `ratio` (default: 2/3) observations going into the training set.
 #'
 #' @section Fields:
 #' See [Resampling].
@@ -14,15 +22,15 @@
 #' @section Methods:
 #' See [Resampling].
 #'
+#' @template seealso_resampling
 #' @export
 #' @examples
 #' # Create a task with 10 observations
-#' task = mlr_tasks$get("iris")
+#' task = tsk("iris")
 #' task$filter(1:10)
 #'
 #' # Instantiate Resampling
-#' rss = mlr_resamplings$get("subsampling",
-#'   param_vals = list(repeats = 2, ratio = 0.5))
+#' rss = rsmp("subsampling", repeats = 2, ratio = 0.5)
 #' rss$instantiate(task)
 #'
 #' # Individual sets:
@@ -34,15 +42,15 @@
 #' rss$instance$train # list of index vectors
 ResamplingSubsampling = R6Class("ResamplingSubsampling", inherit = Resampling,
   public = list(
-    initialize = function(id = "subsampling", param_vals = list(repeats = 30L, ratio = 2 / 3)) {
+    initialize = function() {
       super$initialize(
-        id = id,
+        id = "subsampling",
         param_set = ParamSet$new(params = list(
           ParamUty$new("stratify", default = NULL),
           ParamInt$new("repeats", lower = 1, tags = "required"),
           ParamDbl$new("ratio", lower = 0, upper = 1, tags = "required"))
         ),
-        param_vals = param_vals
+        param_vals = list(repeats = 30L, ratio = 2 / 3)
       )
     }
   ),
