@@ -2,10 +2,18 @@ ids = function(x) {
   map_chr(unname(x), "id")
 }
 
+task_types = function(x) {
+  unique(map_chr(unname(x), "task_type"))
+}
+
 hashes = function(x) {
   map_chr(unname(x), "hash")
 }
 
+hash = function(...) {
+  digest::digest(list(...), algo = "xxhash64")
+}
+
 # updating join:
 # replaces values in x with values in y
 ujoin = function(x, y, key) {
@@ -14,34 +22,6 @@ ujoin = function(x, y, key) {
   x[y, eval(expr), on = key]
 }
 
-distinct = function(x, drop = TRUE) {
-  if (is.logical(x) && !drop) {
-    lvls = c(FALSE, TRUE)
-  } else if (is.factor(x)) {
-    lvls = levels(x)
-    if (drop) {
-      lvls = lvls[lvls %in% x]
-    }
-  } else {
-    lvls = unique(x)
-    lvls = lvls[!is.na(lvls)]
-  }
-  lvls
-}
-
-filter_oob_index = function(x, lower, upper) {
-  x = assert_integerish(x, coerce = TRUE)
-  x[!is.na(x) & x >= lower & x <= upper]
-}
-
-hash = function(...) {
-  digest::digest(list(...), algo = "xxhash64")
-}
-
-hash_resample_iteration = function(task, learner, resampling) {
-  hash(task$hash, learner$hash, resampling$hash)
-}
-
 translate_types = function(x) {
   r_types = mlr_reflections$task_feature_types
   p_types = names(mlr_reflections$task_feature_types)
