@@ -2,9 +2,8 @@ context("MeasureClassif")
 
 test_that("Classification measures", {
   keys = mlr_measures$keys()
-  task = mlr_tasks$get("sonar")
-  learner = mlr_learners$get("classif.featureless")
-  learner$predict_type = "prob"
+  task = tsk("sonar")
+  learner = lrn("classif.featureless", predict_type = "prob")
   learner$train(task)
   p = learner$predict(task)
 
@@ -12,7 +11,7 @@ test_that("Classification measures", {
     m = mlr_measures$get(key)
     if (is.na(m$task_type) || m$task_type == "classif") {
       if (key == "classif.costs") {
-        costs = 1 - diag(task$class_n)
+        costs = 1 - diag(length(task$class_names))
         rownames(costs) = colnames(costs) = task$class_names
         m$costs = costs
       }
