@@ -2,8 +2,8 @@ context("benchmark")
 
 tasks = mlr_tasks$mget(c("iris", "sonar"))
 learners = mlr_learners$mget(c("classif.featureless", "classif.rpart"))
-resamplings = mlr_resamplings$mget("cv3")
-design = expand_grid(tasks, learners, resamplings)
+resamplings = rsmp("cv", folds = 3)
+design = benchmark_grid(tasks, learners, resamplings)
 bmr = benchmark(design)
 
 test_that("Basic benchmarking", {
@@ -12,11 +12,12 @@ test_that("Basic benchmarking", {
 
   tab = as.data.table(bmr)
   expect_data_table(tab, nrows = 12L, ncols = 6L)
-  expect_names(names(tab), permutation.of = c("hash", "task", "learner", "resampling", "iteration", "prediction"))
+  expect_names(names(tab), must.include = c("hash", "task", "learner", "resampling", "iteration", "prediction"))
+  measures = list(msr("classif.acc"))
 
-  tab = bmr$performance(ids = FALSE)
-  expect_data_table(tab, nrows = 12L, ncols = 7L)
-  expect_names(names(tab), permutation.of = c("hash", "task", "learner", "resampling", "iteration", "prediction", "classif.ce"))
+  tab = bmr$performance(measures, ids = FALSE)
+  expect_data_table(tab, nrows = 12L, ncols = 6L + length(measures))
+  expect_names(names(tab), must.include = c("nr", "task", "learner", "resampling", "iteration", "prediction", ids(measures)))
 
   tab = bmr$tasks
   expect_data_table(tab, nrows = 2, any.missing = FALSE)
@@ -33,36 +34,43 @@ test_that("Basic benchmarking", {
   expect_names(names(tab), permutation.of = c("resampling_hash", "resampling", "resampling_id"))
   expect_hash(tab$resampling_hash, len = 2L)
 
-  tab = bmr$aggregate()
+  tab = bmr$aggregate(measures)
   expect_data_table(tab, nrows = 4L)
-  expect_names(names(tab), type = "unique", permutation.of = c("hash", "resample_result", "task_id", "learner_id", "resampling_id", "classif.ce"))
+  expect_names(names(tab), type = "unique", must.include = c("nr", "resample_result", "task_id", "learner_id", "resampling_id", ids(measures)))
 })
 
 test_that("ResampleResult / hash", {
-  aggr = bmr$aggregate()
-  hashes = aggr$hash
-  expect_character(hashes, len = 4L, any.missing = FALSE, unique = TRUE)
+  m = msr("classif.ce")
+  aggr = bmr$aggregate(m)
+  nr = aggr$nr
+  expect_integer(nr, len = 4L, any.missing = FALSE, unique = TRUE)
 
-  for (i in seq_along(hashes)) {
+  for (i in nr) {
     rr = aggr$resample_result[[i]]
     expect_resample_result(rr)
-    expect_equivalent(rr$aggregate(), aggr[["classif.ce"]][i])
-    expect_equal(hashes[i], rr$hash)
+    expect_equivalent(rr$aggregate(m), aggr[["classif.ce"]][i])
+    expect_equal(bmr$hashes[i], rr$hash)
   }
 })
 
 
 test_that("discarding model", {
-  bmr = benchmark(expand_grid(tasks[1L], learners[1L], resamplings), ctrl = mlr_control(store_models = TRUE))
-  expect_false(every(map(bmr$data$learner, "model"), is.null))
-  bmr = benchmark(expand_grid(tasks[1L], learners[1L], resamplings), ctrl = mlr_control(store_models = FALSE))
+  bmr = benchmark(benchmark_grid(tasks[1L], learners[1L], resamplings))
   expect_true(every(map(bmr$data$learner, "model"), is.null))
+  bmr = benchmark(benchmark_grid(tasks[1L], learners[1L], resamplings), store_models = TRUE)
+  expect_false(every(map(bmr$data$learner, "model"), is.null))
 })
 
 test_that("bmr$combine()", {
-  bmr_new = benchmark(expand_grid(mlr_tasks$mget("pima"), learners, resamplings))
+  bmr_new = benchmark(benchmark_grid(mlr_tasks$mget("pima"), learners, resamplings))
   bmr_combined = bmr$clone(deep = TRUE)$combine(bmr_new)
 
+
+  # new bmr gets pasted at the end of data so hashes do net get mixed up?
+  pos_old = match(bmr$hashes, bmr_combined$hashes)
+  pos_new = match(bmr_new$hashes, bmr_combined$hashes)
+  expect_true(all(pos_old < min(pos_new)))
+
   expect_benchmark_result(bmr)
   expect_benchmark_result(bmr_new)
   expect_benchmark_result(bmr_combined)
@@ -76,21 +84,26 @@ test_that("bmr$combine()", {
   expect_true("pima" %in% bmr_combined$tasks$task_id)
 })
 
-test_that("bmr$resample_result() + bmr$best()", {
-  hashes = as.data.table(bmr)$hash
-  expect_resample_result(bmr$resample_result(hashes[1L]))
+test_that("empty bmr", {
+  bmr_new = BenchmarkResult$new()
+  expect_benchmark_result(bmr_new)
 
-  best_ce = bmr$best("classif.ce")
-  expect_resample_result(best_ce)
-  best_acc = bmr$best("classif.acc")
-  expect_resample_result(best_acc)
-  expect_equivalent(best_ce$aggregate("classif.ce"), 1 - best_acc$aggregate("classif.acc"))
+  bmr_new$combine(NULL)
+  expect_benchmark_result(bmr_new)
+
+  bmr_new$combine(bmr)
+  expect_benchmark_result(bmr_new)
+  expect_data_table(bmr_new$data, nrows = nrow(bmr$data))
+})
+
+test_that("bmr$resample_result()", {
+  expect_resample_result(bmr$resample_result(1L))
 })
 
 test_that("inputs are cloned", {
-  task = mlr_tasks$get("iris")
-  learner = mlr_learners$get("classif.featureless")
-  resampling = mlr_resamplings$get("holdout")
+  task = tsk("iris")
+  learner = lrn("classif.featureless")
+  resampling = rsmp("holdout")
 
   expect_error(benchmark(data.table(task = list(task), learner = list(learner), resampling = list(resampling))), "instantiated")
   bmr = benchmark(design = data.table(task = list(task), learner = list(learner), resampling = list(resampling$instantiate(task))))
@@ -112,28 +125,28 @@ test_that("memory footprint", {
 })
 
 test_that("multiple measures", {
-  tasks = mlr_tasks$mget(c("iris", "sonar"))
-  learner = mlr_learners$get("classif.featureless")
-  measures = mlr_measures$mget(c("classif.ce", "classif.acc"))
-  bmr = benchmark(design = expand_grid(tasks, learner, "cv3"))
+  tasks = list(tsk("iris"), tsk("sonar"))
+  learner = lrn("classif.featureless")
+  measures = list(msr("classif.ce"), msr("classif.acc"))
+  bmr = benchmark(design = benchmark_grid(tasks, learner, rsmp("cv", folds = 3)))
   expect_subset(c("classif.ce", "classif.acc"), names(bmr$aggregate(measures)))
 })
 
 test_that("predict_type is checked", {
-  task = mlr_tasks$get("sonar")
-  learner = mlr_learners$get("classif.featureless")
-  resampling = mlr_resamplings$get("cv", param_vals = list(folds = 3L))
-  design = expand_grid(task, learner, resampling)
+  task = tsk("sonar")
+  learner = lrn("classif.featureless")
+  resampling = rsmp("cv", folds = 3L)
+  design = benchmark_grid(task, learner, resampling)
   bmr = benchmark(design)
   expect_error(bmr$aggregate("classif.auc", "predict_type"))
 })
 
 test_that("custom resampling (#245)", {
-  task_boston = mlr_tasks$get("boston_housing")
+  task_boston = tsk("boston_housing")
   task_boston$set_col_role(c("chas", "town"), new_roles = "label")
-  lrn = mlr_learners$get("regr.featureless")
+  lrn = lrn("regr.featureless")
 
-  rdesc = mlr_resamplings$get("custom")
+  rdesc = rsmp("custom")
   train_sets = list((1:200), (1:300), (1:400))
   test_sets = list((201:301), (301:401), (401:501))
   rdesc$instantiate(task_boston, train_sets, test_sets)
@@ -150,22 +163,21 @@ test_that("extract params", {
   lrns = mlr_learners$mget(c("classif.rpart", "classif.rpart", "classif.rpart"))
   lrns[[1]]$param_set$values = list()
   lrns[[2]]$param_set$values = list(xval = 0, cp = 0.1)
-  bmr = benchmark(expand_grid("wine", lrns, "cv3"))
+  bmr = benchmark(benchmark_grid(tsk("wine"), lrns, rsmp("cv", folds = 3)))
   aggr = bmr$aggregate(params = TRUE)
   expect_list(aggr$params[[1]], names = "unique", len = 0L)
   expect_list(aggr$params[[2]], names = "unique", len = 2L)
   expect_list(aggr$params[[3]], names = "unique", len = 1L)
 
-
   # only one params
   lrns = mlr_learners$mget(c("classif.featureless"))
-  bmr = benchmark(expand_grid("wine", lrns, "cv3"))
+  bmr = benchmark(benchmark_grid(tsk("wine"), lrns, rsmp("cv", folds = 3)))
   aggr = bmr$aggregate(params = TRUE)
   expect_list(aggr$params[[1]], names = "unique", len = 1L)
 
   # no params
   lrns = mlr_learners$mget(c("classif.debug"))
-  bmr = benchmark(expand_grid("wine", lrns, "cv3"))
+  bmr = benchmark(benchmark_grid(tsk("wine"), lrns, rsmp("cv", folds = 3)))
   aggr = bmr$aggregate(params = TRUE)
   expect_list(aggr$params[[1]], names = "unique", len = 0L)
 })
